@@ -8,22 +8,26 @@
  * SPDX-License-Identifier: EPL-2.0
  **********************************************************************/
 
+import UpdateCommand from '@oclif/plugin-update/lib/commands/update'
 import axios from 'axios'
 import { cli } from 'cli-ux'
 import * as commandExists from 'command-exists'
 import * as fs from 'fs-extra'
+import * as getos from 'getos'
 import * as https from 'https'
 import * as yaml from 'js-yaml'
 import * as notifier from 'node-notifier'
+import * as os from 'os'
 import * as path from 'path'
-
-const pkjson = require('../package.json')
+import { promisify } from 'util'
 
 import { ChectlContext } from './api/context'
 import { KubeHelper } from './api/kube'
 import { VersionHelper } from './api/version'
 import { DEFAULT_CHE_NAMESPACE, LEGACY_CHE_NAMESPACE } from './constants'
 
+const pkjson = require('../package.json')
+
 export const KUBERNETES_CLI = 'kubectl'
 export const OPENSHIFT_CLI = 'oc'
 
@@ -165,9 +169,10 @@ export function notifyCommandCompletedSuccessfully(): void {
 export async function askForChectlUpdateIfNeeded(): Promise<void> {
   const ctx = ChectlContext.get()
   if (await VersionHelper.isChectlUpdateAvailable(ctx[ChectlContext.CACHE_DIR])) {
-    cli.info('A newer version of crwctl is available.')
-    if (await cli.confirm('To deploy the latest version of CodeReady Workspaces you have to update crwctl first [y/n]')) {
-      cli.info('Please run "crwctl update" and then repeat "server:deploy" command.')
+    cli.info('A more recent version of crwctl is available. To deploy the latest version of CodeReady Workspaces, update the crwctl tool first.')
+    if (await cli.confirm('Do you want to update crwctl now? [y/n]')) {
+      // Update crwctl
+      await UpdateCommand.run([])
       cli.exit(0)
     }
   }
@@ -272,3 +277,18 @@ export async function findWorkingNamespace(flags: any): Promise<string> {
 
   return DEFAULT_CHE_NAMESPACE
 }
+
+/**
+ * Return linux distribution if crwctl command is executed in linux
+ */
+export async function getDistribution(): Promise<string | undefined> {
+  if (os.platform() === 'linux') {
+    try {
+      const platorm = await promisify(getos)() as getos.LinuxOs
+      return platorm.dist
+    } catch {
+      return
+    }
+  }
+  return
+}
